# inked

inked is a simple Python package that allows you to add **image** or **text** watermarks to your images. You can position the watermark anywhere on the image using custom or predefined positions.

## Installation

You can install the package using pip:

```bash
pip install inked
